.. -*- mode: ReST -*-

.. _abstract:

=============
Abstract APIs
=============

.. contents:: Contents

This module provides various abstractions for reuse, including:

1. Protocols
2. Type Aliases
3. An import Prelude
   

See :ref:`jgdv._abstract` for the classes.

    
